About pyEEG
-----------

Authors
~~~~~~~

List of contributing authors:

- Hugo Weissbart <hugo.weissbart12@imperial.ac.uk>
- Karen Wendt <karen.wendt15@imperial.ac.uk>
- Octave Etard <octave.etard11@imperial.ac.uk>

Github
~~~~~~

You can find the source code of the project at https://github.com/Hugo-W/pyEEG.

Contributing
''''''''''''

Don't hesitate to clone the project, create your branch, add features
and whatever want to see in this library, and ask for a **pull request** so
that other contributors can review the code.

If there are issues with some part of the code, or a feature you wish
to be present in the library, or simply a suggestion about anything, please `open an issue`_.

.. _open an issue : https:www.github.com/Hugo-W/pyEEG/issues
